@@ -152,10 +152,10 @@ int main(int argc, char **argv)
 
     /* Test server cipher selection and scsv detection */
     {
-        struct s2n_connection *conn;
-        struct s2n_config *server_config;
-        char *rsa_cert_chain_pem, *rsa_private_key_pem, *ecdsa_cert_chain_pem, *ecdsa_private_key_pem;
-        struct s2n_cert_chain_and_key *rsa_cert, *ecdsa_cert;
+        struct s2n_connection *conn = NULL;
+        struct s2n_config *server_config = NULL;
+        char *rsa_cert_chain_pem = NULL, *rsa_private_key_pem = NULL, *ecdsa_cert_chain_pem = NULL, *ecdsa_private_key_pem = NULL;
+        struct s2n_cert_chain_and_key *rsa_cert = NULL, *ecdsa_cert = NULL;
         /* Allocate all of the objects and PEMs we'll need for this test. */
         EXPECT_NOT_NULL(rsa_cert_chain_pem = malloc(S2N_MAX_TEST_PEM_SIZE));
         EXPECT_NOT_NULL(rsa_private_key_pem = malloc(S2N_MAX_TEST_PEM_SIZE));
