@@ -133,9 +133,6 @@ static const char *message_names[] = {
     MESSAGE_NAME_ENTRY(CLIENT_NPN),
 };
 
-/* Maximum number of messages in a handshake */
-#define S2N_MAX_HANDSHAKE_LENGTH    32
-
 /* We support different ordering of TLS Handshake messages, depending on what is being negotiated. There's also a dummy "INITIAL" handshake
  * that everything starts out as until we know better.
  */
@@ -1336,13 +1333,10 @@ static int s2n_handshake_handle_sslv2(struct s2n_connection *conn)
     POSIX_GUARD(s2n_stuffer_wipe(&conn->handshake.io));
 
     /* We're done with the record, wipe it */
-    POSIX_GUARD(s2n_stuffer_wipe(&conn->header_in));
-    POSIX_GUARD(s2n_stuffer_wipe(&conn->in));
+    POSIX_GUARD_RESULT(s2n_record_wipe(conn));
 
     WITH_ERROR_BLINDING(conn, POSIX_GUARD(r));
 
-    conn->in_status = ENCRYPTED;
-
     /* Advance the state machine */
     POSIX_GUARD(s2n_advance_message(conn));
 
@@ -1360,15 +1354,6 @@ static int s2n_try_delete_session_cache(struct s2n_connection *conn)
     return S2N_SUCCESS;
 }
 
-static S2N_RESULT s2n_wipe_record(struct s2n_connection *conn)
-{
-    RESULT_ENSURE_REF(conn);
-    RESULT_GUARD_POSIX(s2n_stuffer_wipe(&conn->header_in));
-    RESULT_GUARD_POSIX(s2n_stuffer_wipe(&conn->in));
-    conn->in_status = ENCRYPTED;
-    return S2N_RESULT_OK;
-}
-
 static S2N_RESULT s2n_finish_read(struct s2n_connection *conn)
 {
     RESULT_ENSURE_REF(conn);
@@ -1409,8 +1394,8 @@ static S2N_RESULT s2n_handshake_app_data_recv(struct s2n_connection *conn)
  */
 static int s2n_handshake_read_io(struct s2n_connection *conn)
 {
-    uint8_t record_type;
-    uint8_t message_type;
+    uint8_t record_type = 0;
+    uint8_t message_type = 0;
     int isSSLv2 = 0;
 
     /* Fill conn->in stuffer necessary for the handshake.
@@ -1439,7 +1424,7 @@ static int s2n_handshake_read_io(struct s2n_connection *conn)
         if ((r < S2N_SUCCESS) && (s2n_errno == S2N_ERR_EARLY_DATA_TRIAL_DECRYPT)) {
             POSIX_GUARD(s2n_stuffer_reread(&conn->in));
             POSIX_GUARD_RESULT(s2n_early_data_record_bytes(conn, s2n_stuffer_data_available(&conn->in)));
-            POSIX_GUARD_RESULT(s2n_wipe_record(conn));
+            POSIX_GUARD_RESULT(s2n_record_wipe(conn));
             return S2N_SUCCESS;
         }
         POSIX_GUARD(r);
@@ -1473,7 +1458,7 @@ static int s2n_handshake_read_io(struct s2n_connection *conn)
         POSIX_GUARD(s2n_stuffer_wipe(&conn->handshake.io));
 
         /* We're done with the record, wipe it */
-        POSIX_GUARD_RESULT(s2n_wipe_record(conn));
+        POSIX_GUARD_RESULT(s2n_record_wipe(conn));
 
         /* Advance the state machine if this was an expected message */
         if (EXPECTED_RECORD_TYPE(conn) == TLS_CHANGE_CIPHER_SPEC && !CONNECTION_IS_WRITER(conn)) {
@@ -1489,7 +1474,7 @@ static int s2n_handshake_read_io(struct s2n_connection *conn)
         /* Ignore record types that we don't support */
 
         /* We're done with the record, wipe it */
-        POSIX_GUARD_RESULT(s2n_wipe_record(conn));
+        POSIX_GUARD_RESULT(s2n_record_wipe(conn));
         return S2N_SUCCESS;
     }
 
@@ -1499,7 +1484,7 @@ static int s2n_handshake_read_io(struct s2n_connection *conn)
     while (s2n_stuffer_data_available(&conn->in)) {
         /* We're done with negotiating but we have trailing data in this record. Bail on the handshake. */
         S2N_ERROR_IF(EXPECTED_RECORD_TYPE(conn) == TLS_APPLICATION_DATA, S2N_ERR_BAD_MESSAGE);
-        int r;
+        int r = 0;
         POSIX_GUARD((r = s2n_read_full_handshake_message(conn, &message_type)));
 
         /* Do we need more data? This happens for message fragmentation */
@@ -1507,7 +1492,7 @@ static int s2n_handshake_read_io(struct s2n_connection *conn)
             /* Break out of this inner loop, but since we're not changing the state, the
              * outer loop in s2n_handshake_io() will read another record.
              */
-            POSIX_GUARD_RESULT(s2n_wipe_record(conn));
+            POSIX_GUARD_RESULT(s2n_record_wipe(conn));
             return S2N_SUCCESS;
         }
 
@@ -1556,7 +1541,7 @@ static int s2n_handshake_read_io(struct s2n_connection *conn)
     }
 
     /* We're done with the record, wipe it */
-    POSIX_GUARD_RESULT(s2n_wipe_record(conn));
+    POSIX_GUARD_RESULT(s2n_record_wipe(conn));
     return S2N_SUCCESS;
 }
 
@@ -1579,9 +1564,7 @@ static int s2n_handle_retry_state(struct s2n_connection *conn)
 
     if (!CONNECTION_IS_WRITER(conn)) {
         /* We're done parsing the record, reset everything */
-        POSIX_GUARD(s2n_stuffer_wipe(&conn->header_in));
-        POSIX_GUARD(s2n_stuffer_wipe(&conn->in));
-        conn->in_status = ENCRYPTED;
+        POSIX_GUARD_RESULT(s2n_record_wipe(conn));
     }
 
     if (CONNECTION_IS_WRITER(conn)) {
